package java.io;

import java.nio.charset.CharsetEncoder;
import java.nio.charset.Charset;
import sun.nio.cs.StreamEncoder;

public class OutputStreamWriter extends Writer
{
    private final StreamEncoder se;
    
    public OutputStreamWriter(OutputStream out, String charsetName) throws UnsupportedEncodingException {
        super(out);
        if (charsetName == null) {
            throw new NullPointerException("charsetName");
        }
        this.se = StreamEncoder.forOutputStreamWriter(out, this, charsetName);
        return;
    }
    
    public OutputStreamWriter(OutputStream out) {
        super(out);
        try {
            this.se = StreamEncoder.forOutputStreamWriter(out, this, (String)null);
        }
        catch (UnsupportedEncodingException cause) {
            throw new Error(cause);
        }
    }
    
    public OutputStreamWriter(OutputStream out, Charset cs) {
        super(out);
        if (cs == null) {
            throw new NullPointerException("charset");
        }
        this.se = StreamEncoder.forOutputStreamWriter(out, this, cs);
        return;
    }
    
    public OutputStreamWriter(OutputStream out, CharsetEncoder enc) {
        super(out);
        if (enc == null) {
            throw new NullPointerException("charset encoder");
        }
        this.se = StreamEncoder.forOutputStreamWriter(out, this, enc);
        return;
    }
    
    public String getEncoding() {
        return this.se.getEncoding();
    }
    
    void flushBuffer() throws IOException {
        this.se.flushBuffer();
    }
    
    @Override
    public void write(int c) throws IOException {
        this.se.write(c);
    }
    
    @Override
    public void write(char[] cbuf, int off, int len) throws IOException {
        this.se.write(cbuf, off, len);
    }
    
    @Override
    public void write(String str, int off, int len) throws IOException {
        this.se.write(str, off, len);
    }
    
    @Override
    public void flush() throws IOException {
        this.se.flush();
    }
    
    @Override
    public void close() throws IOException {
        this.se.close();
    }
}
